aboutsummaryrefslogtreecommitdiff
path: root/toys/example/demo_many_options.c
diff options
context:
space:
mode:
Diffstat (limited to 'toys/example/demo_many_options.c')
-rw-r--r--toys/example/demo_many_options.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/toys/example/demo_many_options.c b/toys/example/demo_many_options.c
index e071d26c..c5680605 100644
--- a/toys/example/demo_many_options.c
+++ b/toys/example/demo_many_options.c
@@ -1,22 +1,22 @@
/* test_many_options.c - test more than 32 bits worth of option flags
*
* Copyright 2015 Rob Landley <rob@landley.net>
-USE_TEST_MANY_OPTIONS(NEWTOY(test_many_options, "ZYXWVUTSRQPONMLKJIHGFEDCBAzyxwvutsrqponmlkjihgfedcba", TOYFLAG_BIN))
+USE_DEMO_MANY_OPTIONS(NEWTOY(demo_many_options, "ZYXWVUTSRQPONMLKJIHGFEDCBAzyxwvutsrqponmlkjihgfedcba", TOYFLAG_BIN))
-config TEST_MANY_OPTIONS
- bool "test_many_options"
+config DEMO_MANY_OPTIONS
+ bool "demo_many_options"
default n
help
- usage: test_many_options -[a-zA-Z]
+ usage: demo_many_options -[a-zA-Z]
Print the optflags value of the command arguments, in hex.
*/
-#define FOR_test_many_options
+#define FOR_demo_many_options
#include "toys.h"
-void test_many_options_main(void)
+void demo_many_options_main(void)
{
xprintf("optflags=%llx\n", toys.optflags);
}
@@ -1,22 +1,22 @@
-/* test_many_options.c - test more than 32 bits worth of option flags
+/* demo_many_options.c - test more than 32 bits worth of option flags
*
* Copyright 2015 Rob Landley <rob@landley.net>